@@ -29,10 +29,10 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univ
   #initialization
   
   #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1);
   stat = 0;
   flag = 0;
-   if ( all(target>0 & target<1) ) ## are they proportions?
+   if ( min(target)>0 & max(target)<1 ) ## are they proportions?
    { 
      target = log( target/(1-target) ) 
    }
@@ -63,9 +63,9 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univ
     if(hash == TRUE)#update hash objects
     {
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
+      pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
@@ -116,9 +116,9 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univ
         if(hash == TRUE)#update hash objects
         {
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
+          pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     }else{ #more than one var
@@ -129,9 +129,9 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univ
           if(hash == TRUE)#update hash objects
           {
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
+            pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -144,9 +144,9 @@ testIndSpearman = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univ
     if(hash == TRUE)#update hash objects
     {
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- 1;#.set(pvalue_hash , key , 1)
+      pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
@@ -200,7 +200,7 @@ res <- tryCatch(
   #last error check
   if(is.na(pvalue) || is.na(stat))
   {
-    pvalue = 1;
+    pvalue = log(1);
     stat = 0;
     flag = 1;
   }else{
@@ -233,7 +233,7 @@ error=function(cond) {
 #   stop();
   
   #error case (we are pretty sure that the only error case is when x,cs are highly correlated and the inversion of the matrix is not possible)
-  pvalue = 1;
+  pvalue = log(1);
   stat = 0;
   flag = 1;
   
